@@ -27,7 +27,7 @@ object_name = os
 __package__ = os.path.basename(os.path.dirname(__file__))
 __author__ = "Dillon"
 __email__ = "aa269440877@outlook.com"
-__version__ = "1.0.8"
+__version__ = "1.0.9"
 __url__ = "https://gitee.com/ld269440877/tools/blob/master/my_modules/dir_objectName.py"
 __license__ = "MIT Licence"
 
@@ -487,11 +487,12 @@ def aprint(sequence_or_mapping, columns=4, width=30, pattern=r"^[^_]"):
 
 def modules_from_package(package_name, pattern=r"^[^_]"):
     modules = list()
+    package_folder = getattr(package_name, '__path__', list(""))[0]
     package_name = package_name.__name__
-    package_folder = getattr(package_name, '__path__', list())[0]
     if not package_folder:
         return list()
-    for module in os.listdir(package_folder):
+    package_modules = os.listdir(package_folder)
+    for module in package_modules:
         try:
             if re.search(pattern, module):
                 module = f"{package_name}." + os.path.splitext(module)[0]
